@@ -1,5 +1,5 @@
 package File::Slurper;
-$File::Slurper::VERSION = '0.003';
+$File::Slurper::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -33,17 +33,18 @@ my $has_utf8_strict = eval { require PerlIO::utf8_strict };
 
 sub _text_layers {
 	my ($encoding, $options) = @_;
-	my $crlf = $options->{crlf} ? $options->{crlf} eq 'auto' ? $crlf_default : !! delete $options->{crlf} : '';
-	# An extra :perlio at the end gives a small speed boost for undetermined reasons.
+	my $crlf = !! delete $options->{crlf};
+	$crlf = $crlf_default if $crlf eq 'auto';
+
 	if ($encoding =~ /^(latin|iso-8859-)1$/i) {
-		return $crlf ? ':unix:crlf:perlio' : ':raw';
+		return $crlf ? ':unix:crlf' : ':raw';
 	}
 	elsif ($has_utf8_strict && $encoding =~ /^utf-?8\b/i) {
-		return $crlf ? ':unix:utf8_strict:crlf:perlio' : ':unix:utf8_strict:perlio';
+		return $crlf ? ':unix:utf8_strict:crlf' : ':unix:utf8_strict';
 	}
 	else {
 		# non-ascii compatible encodings such as UTF-16 need encoding before crlf
-		return $crlf ? ":raw:encoding($encoding):crlf:perlio" : ":raw:encoding($encoding):perlio";
+		return $crlf ? ":raw:encoding($encoding):crlf" : ":raw:encoding($encoding)";
 	}
 }
 
@@ -96,7 +97,7 @@ sub read_dir {
 
 1;
 
-# ABSTRACT: A simple, sane and efficient file slurper
+# ABSTRACT: A simple, sane and efficient module to slurp a file
 
 __END__
 
@@ -106,11 +107,11 @@ __END__
 
 =head1 NAME
 
-File::Slurper - A simple, sane and efficient file slurper
+File::Slurper - A simple, sane and efficient module to slurp a file
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -181,6 +182,14 @@ This will prepend C<$dir> to the entries
 
 =back
 
+=head1 RATIONALE
+
+This module tries to make it as easy as possible to read and write files correctly and fast. The most correct way of doing this is not always obvious (e.g. L<#83126|https://rt.cpan.org/Public/Bug/Display.html?id=83126>), and just as often the most obvious correct way is not the fastest correct way. This module hides away all such complications behind an easy intuitive interface.
+
+=head1 DEPENDENCIES
+
+This module has an optional dependency on PerlIO::utf8_strict. Installing this will make UTF-8 encoded IO significantly faster, but should not otherwise affect the operation of this module. This may change into a dependency on the related Unicode::UTF8 in the future.
+
 =head1 SEE ALSO
 
 =over 4
